@@ -101,7 +101,9 @@ class ShellCommand(Command):
     
     parser = Command.standard_parser(simulate=True)
 
-    def command(self):        
+    def command(self):
+        self.verbose = 3
+        
         if len(self.args) == 0:
             # Assume the .ini file is ./development.ini
             config_file = 'development.ini'
